@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2014-2021 Mike Fährmann
+# Copyright 2014-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -49,16 +49,21 @@ class SankakuExtractor(BooruExtractor):
             self.log.warning(
                 "Login required to download 'contentious_content' posts")
             SankakuExtractor._warning = False
+        elif url[8] == "v":
+            url = "https://s.sankakucomplex.com" + url[url.index("/", 8):]
         return url
 
-    @staticmethod
-    def _prepare(post):
+    def _prepare(self, post):
         post["created_at"] = post["created_at"]["s"]
         post["date"] = text.parse_timestamp(post["created_at"])
         post["tags"] = [tag["name"] for tag in post["tags"] if tag["name"]]
         post["tag_string"] = " ".join(post["tags"])
+        post["_http_validate"] = self._check_expired
 
-    def _extended_tags(self, post):
+    def _check_expired(self, response):
+        return not response.history or '.com/expired.png' not in response.url
+
+    def _tags(self, post, page):
         tags = collections.defaultdict(list)
         types = self.TAG_TYPES
         for tag in post["tags"]:
@@ -79,8 +84,8 @@ class SankakuTagExtractor(SankakuExtractor):
     test = (
         ("https://sankaku.app/?tags=bonocho", {
             "count": 5,
-            "pattern": r"https://v\.sankakucomplex\.com/data/[^/]{2}/[^/]{2}"
-                       r"/[^/]{32}\.\w+\?e=\d+&expires=\d+&m=[^&#]+",
+            "pattern": r"https://s\.sankakucomplex\.com/data/[^/]{2}/[^/]{2}"
+                       r"/[^/]{32}\.\w+\?e=\d+&(expires=\d+&)?m=[^&#]+",
         }),
         ("https://beta.sankakucomplex.com/?tags=bonocho"),
         ("https://chan.sankakucomplex.com/?tags=bonocho"),
@@ -160,7 +165,7 @@ class SankakuPostExtractor(SankakuExtractor):
         }),
         # 'contentious_content'
         ("https://sankaku.app/post/show/21418978", {
-            "pattern": r"https://v\.sankakucomplex\.com"
+            "pattern": r"https://s\.sankakucomplex\.com"
                        r"/data/13/3c/133cda3bfde249c504284493903fb985\.jpg",
         }),
         # empty tags (#1617)
@@ -217,7 +222,11 @@ class SankakuAPI():
 
     def __init__(self, extractor):
         self.extractor = extractor
-        self.headers = {"Accept": "application/vnd.sankaku.api+json;v=2"}
+        self.headers = {
+            "Accept" : "application/vnd.sankaku.api+json;v=2",
+            "Origin" : extractor.root,
+            "Referer": extractor.root + "/",
+        }
 
         self.username, self.password = self.extractor._get_auth_info()
         if not self.username:
@@ -251,11 +260,14 @@ class SankakuAPI():
         for _ in range(5):
             self.authenticate()
             response = self.extractor.request(
-                url, params=params, headers=self.headers, fatal=False)
+                url, params=params, headers=self.headers, fatal=None)
 
             if response.status_code == 429:
-                self.extractor.wait(
-                    until=response.headers.get("X-RateLimit-Reset"))
+                until = response.headers.get("X-RateLimit-Reset")
+                if not until and b"tags-limit" in response.content:
+                    raise exception.StopExtraction("Search tag limit exceeded")
+                seconds = None if until else 60
+                self.extractor.wait(until=until, seconds=seconds)
                 continue
 
             data = response.json()
@@ -276,9 +288,41 @@ class SankakuAPI():
         params["lang"] = "en"
         params["limit"] = str(self.extractor.per_page)
 
+        refresh = self.extractor.config("refresh", False)
+        if refresh:
+            offset = expires = 0
+            from time import time
+
         while True:
             data = self._call(endpoint, params)
-            yield from data["data"]
+
+            if refresh:
+                posts = data["data"]
+                if offset:
+                    posts = util.advance(posts, offset)
+
+                for post in posts:
+                    if not expires:
+                        url = post["file_url"]
+                        if url:
+                            expires = text.parse_int(
+                                text.extr(url, "e=", "&")) - 60
+
+                    if 0 < expires <= time():
+                        self.extractor.log.debug("Refreshing download URLs")
+                        expires = None
+                        break
+
+                    offset += 1
+                    yield post
+
+                if expires is None:
+                    expires = 0
+                    continue
+                offset = expires = 0
+
+            else:
+                yield from data["data"]
 
             params["next"] = data["meta"]["next"]
             if not params["next"]:
